<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://www.fixel.ai
 * @since      2.0.0
 *
 * @package    fixel
 * @subpackage fixel/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    fixel
 * @subpackage fixel/public
 * @author     Fixel <stores@fixel.ai>
 */
class fixel_Public {

    /**
     * The ID of this plugin.
     *
     * @since    2.0.0
     * @access   private
     * @var      string    $fixel    The ID of this plugin.
     */
    private $fixel;

    /**
     * The version of this plugin.
     *
     * @since    2.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    2.0.0
     * @param      string    $fixel       The name of the plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct( $fixel, $version ) {

        $this->fixel = $fixel;
        $this->version = $version;
        $this->fxl_conversion();

    }

    /**
     * Register the stylesheets for the public-facing side of the site.
     *
     * @since    2.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in fixel_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The fixel_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_style( $this->fixel, plugin_dir_url( __FILE__ ) . 'css/fixel-public.css', array(), $this->version, 'all' );

    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    2.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in fixel_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The fixel_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */

        wp_enqueue_script( $this->fixel, plugin_dir_url( __FILE__ ) . 'js/fixel-public.js', array( 'jquery' ), $this->version, false );
        // check if Fixel code is defined and if it is register the code
        $FXL_CODE = get_option('fxl_segment_code');
        if(!$FXL_CODE){
            // try getting old FXL code to support v1.0.0 of Fixel WP
            $FXL_CODE = get_option('fxl_insert_header');
        }
        if($FXL_CODE) {
            $script_src = "https://script.fixel.ai/script/Fixel.min.js?src=WP&fxl_code={$FXL_CODE}";
            wp_enqueue_script('fxl_pxl_script',$script_src);
        }

    }

    public function fxl_conversion(){
        if( !function_exists('is_plugin_active') ) {
            include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
        }

        if ( is_plugin_active( 'woocommerce/woocommerce.php') ) {
            // Do what you want in case woocommerce is installed
            // We attach our logic to the already existing woocommerce hook of thankyou
            add_action('woocommerce_thankyou', array($this,'report_to_fxl_conversion' ));
        }
    }

    /**
     * Add js call script tag purchase
     * @param $order_id
     * @since 2.2.3
     */
    public function report_to_fxl_conversion($order_id)
    {
        if (function_exists('is_wc_endpoint_url') && function_exists('wc_get_order')) {
            if (!is_wc_endpoint_url('order-received'))
                return;
            if(!$order_id)
                $order_id = absint(get_query_var('order-received')); // Get the order ID

            $order = wc_get_order($order_id); // Get the WC_Order Object
            $orderTotal = $order->get_total();
            // Only for processing orders
            if (!is_a($order, 'WC_Order') || !$order->has_status('processing')) {
                return;
            }

            $FXL_CODE = get_option('fxl_segment_code');
            if($FXL_CODE){
                $fxl_front_script = "<script id=\"fxl_conversions\" fxl_code=\"{$FXL_CODE}\" src=\"https://script.fixel.ai/script/conversions/fxl_conversions_v4.js\"></script>";
                $fxl_front_script .= "<script>" . PHP_EOL;
                $fxl_front_script .= "window.fxl && fxl('Purchase',{value: {$orderTotal} })";
                $fxl_front_script .= "</script>";
                echo $fxl_front_script;
            }
        }
    }

}